.. Django-Select2 documentation master file, created by
   sphinx-quickstart on Sat Aug 25 10:23:46 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

All Contents
============

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   get_started
   django_select2
   extra
   CONTRIBUTING

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
